#ifndef NT2_INCLUDE_FUNCTIONS_RAT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_RAT_HPP_INCLUDED

#include <nt2/combinatorial/include/functions/rat.hpp>

#endif
